
package my_scalation

import scalation.mathstat._

// runMain my_scalation.tranRegressionTest

import scala.math.sqrt

import scalation._
import scalation.mathstat._
import scalation.modeling._

@main def tranRegressionTest (): Unit =

    // 8 data points: xy
    val xy = MatrixD ((8, 2), 1,  2,                        // 8-by-2 combined matrix
                              2,  5,
                              3, 10,
                              4, 15,
                              5, 20,
                              6, 30,
                              7, 50,
                              8, 60)

    val x_fname  = Array ("x")                              // names of features/variables for x
    val ox_fname = Array ("_1", "x")                        // names of features/variables for ox

    println ("model: y = b0 + b1*x1 + b2*x1^2")
    println (s"xy = $xy")

    val oxy     = VectorD.one (xy.dim) +^: xy               // combined matrix: ones column prepended
    val (ox, y) = (oxy.not(?, 2), oxy(?, 2))                // (data matrix, response column)
    val x       = xy.not(?, 1)                              // data matrix with no ones column

    banner ("Regression")
    val reg = Regression (oxy, ox_fname)()                  // create a Regression model
    reg.trainNtest ()()                                     // train and test the model
    println (reg.summary ())                                // parameter/coefficient statistics
    val yp = reg.predict (ox)                               // y predicted for Regression

    banner ("Quadrastic Regression")
    val qrg = SymbolicRegression.quadratic (x, y, x_fname)  // create a Quadratic Regression model
    qrg.trainNtest ()()                                     // train and test the model
    println (qrg.summary ())                                // parameter/coefficient statistics
    val yp2 = qrg.predict (qrg.getX)                        // y predicted for Quadratic Regression

    banner ("Transformed Regression")
    val mod = new TranRegression (ox, y, ox_fname, Regression.hp,
                                  sqrt _, sq _)             // sqrt Transformed Regression model
    mod.trainNtest ()()                                     // train and test the model
    println (mod.summary ())                                // parameter/coefficient statistics
    val yp3 = mod.predict (ox)                              // y predicted for Transformed Regression

    val mat = MatrixD (y, yp, yp2, yp3)
    println (s"mat = $mat")
    new PlotM (null, mat, null, "y vs. yp vs. yp2 vs. yp3", true)
    
end tranRegressionTest

